@@ -16,9 +16,7 @@
 #' @param out_folder `character` Main output folder, default: NULL.
 #' @param out_folder_mod `character` Output folder for original HDF storage, default: $tempdir
 #' @param opts_file `character` full path to a JSON file
-#'  containing MODIStsp processing options saved from the GUI. If NULL,
-#'  parameters of the last successful run are retrieved from file
-#'  "MODIStsp_Previous.json" in subfolder "Previous"), Default: NULL
+#'  containing MODIStsp processing options saved from the GUI, Default: NULL
 #' @param selprod `character` Name of selected MODIS product (e.g.,
 #'   Vegetation Indexes_16Days_250m (M*D13Q1)). You can get
 #'   a list of available product names using function `MODIStsp_get_prodnames`,
@@ -409,7 +407,8 @@ MODIStsp <- function(...,
       # Load default values - to avoid overwriting always the loaded
       # parameters with default, we set the defaults here rather than
       # in the initialization of the function!
-      proc_opts <- jsonlite::read_json(system.file("ExtData/Previous/mstp_defaults.json",
+      proc_opts <- jsonlite::read_json(system.file("ExtData",
+                                                   "mstp_defaults.json",
                                                    package = "MODIStsp"))
     }
 
@@ -538,20 +537,4 @@ MODIStsp <- function(...,
                      verbose = verbose)
   }
 
-
-  # Save previous options ----
-
-  # At the end of a successful execution, save the options used in the main
-  # output folder as a JSON file with name containing the date of processing.
-  # Also update "MODIStsp_previous.json.
-
-  if (!is.null(proc_opts)) {
-    if (is.null(proc_opts$spafile))  proc_opts$spafile <- NA
-    if (is.null(proc_opts$drawnext)) proc_opts$drawnext <- NA
-    if (all(unlist(proc_opts$bbox) == NULL)) proc_opts$bbox <- c(NA, NA, NA, NA)
-    opts_jsfile <- file.path(proc_opts$out_folder,
-                             paste0("MODIStsp_", Sys.Date(), ".json"))
-    jsonlite::write_json(proc_opts, opts_jsfile, pretty = TRUE,
-                         auto_unbox = TRUE)
-  }
 }
